@@ -43,7 +43,7 @@ na.seadec <- function(x, algorithm = "interpolation" , ...) {
   
   # Multivariate Input Handling (loop through all columns)
   # No imputation code in this part. 
-  if (!is.null( dim(data)[2]) && dim(data)[2] != 1  ) {
+  if (!is.null( dim(data)[2])  ) {
     for (i in 1:dim(data)[2]) {
       #if imputing a column does not work (mostly because it is not numeric) the column is left unchanged
       tryCatch(data[,i] <- na.seadec(data[ ,i], algorithm, ...), error=function(cond) {
