@@ -67,13 +67,13 @@ plotNA.imputations <- function(x.withNA, x.withImputations, x.withTruth = NULL,
   ## Input check
   ## 
   
-  if(!is.null(dim(data.withNA)))
+  if(!is.null(dim(data.withNA)) && dim(data.withNA)[2] != 1)
   {stop("Input x.withNA is not univariate")}
   
   if(!is.numeric(data.withNA))
   {stop("Input x.withNA is not numeric")}
   
-  if(!is.null(dim(x.withImputations)))
+  if(!is.null(dim(data.withImputations)) && dim(data.withImputations)[2] != 1)
   {stop("Input x.withImputations is not univariate")}
   
   if(!is.numeric(x.withImputations))
@@ -108,7 +108,7 @@ plotNA.imputations <- function(x.withNA, x.withImputations, x.withTruth = NULL,
   }
   else {
     #check also if data.withTruth has right format
-    if(!is.null(dim(data.withTruth)))
+    if(!is.null(dim(data.withTruth)) && dim(data.withTruth)[2] != 1)
     {stop("Input x.withTruth is not univariate")}
     
     if(!is.numeric(data.withTruth))
